==> haskell-tdigest-0.2.1.1-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tdigest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tdigest
version:              0.2.1.1
visibility:           public
id:                   tdigest-0.2.1.1-IF1lqgY91oBFN33LP6dOXq
key:                  tdigest-0.2.1.1-IF1lqgY91oBFN33LP6dOXq
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/haskell-tdigest#readme
synopsis:             On-line accumulation of rank-based statistics
description:
    A new data structure for accurate on-line accumulation of rank-based statistics such as quantiles and trimmed means.

    See original paper: "Computing extremely accurate quantiles using t-digest" by Ted Dunning and Otmar Ertl
    for more details <https://github.com/tdunning/t-digest/blob/07b8f2ca2be8d0a9f04df2feadad5ddc1bb73c88/docs/t-digest-paper/histo.pdf>.

category:             Numeric
abi:                  ebcc4862fac6cab3fe85c1d29e8bf0a2
exposed:              True
exposed-modules:
    Data.TDigest Data.TDigest.Internal Data.TDigest.NonEmpty
    Data.TDigest.Postprocess Data.TDigest.Postprocess.Internal
    Data.TDigest.Tree Data.TDigest.Tree.Internal
    Data.TDigest.Tree.NonEmpty Data.TDigest.Tree.Postprocess
    Data.TDigest.Vector Data.TDigest.Vector.Internal
    Data.TDigest.Vector.NonEmpty Data.TDigest.Vector.Postprocess

import-dirs:          /usr/lib/ghc-9.0.1/site-local/tdigest-0.2.1.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/tdigest-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/tdigest-0.2.1.1
hs-libraries:         HStdigest-0.2.1.1-IF1lqgY91oBFN33LP6dOXq
depends:
    base-4.15.0.0 base-compat-0.11.2-EfuzzJ3SbjR74eBdJgKfBC
    binary-0.8.8.0 deepseq-1.4.5.0
    reducers-3.12.3-Ckxj1WMvoRtAxa7fOWNU5j
    semigroupoids-5.3.5-JeS6w5gGBwN3loA1zRj8Hq transformers-0.5.6.2
    vector-0.12.3.0-7AyAfn90uRLJwvulX46pQG
    vector-algorithms-0.8.0.4-KDi9Z5tJW2y2zQ5Bmwii66

haddock-interfaces:   /usr/share/doc/haskell-tdigest/html/tdigest.haddock
haddock-html:         /usr/share/doc/haskell-tdigest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tdigest-0.2.1.1-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tdigest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tdigest
version:              0.2.1.1
visibility:           public
id:                   tdigest-0.2.1.1-CR2sQLb4NUj6mvxIST6jsM
key:                  tdigest-0.2.1.1-CR2sQLb4NUj6mvxIST6jsM
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/haskell-tdigest#readme
synopsis:             On-line accumulation of rank-based statistics
description:
    A new data structure for accurate on-line accumulation of rank-based statistics such as quantiles and trimmed means.

    See original paper: "Computing extremely accurate quantiles using t-digest" by Ted Dunning and Otmar Ertl
    for more details <https://github.com/tdunning/t-digest/blob/07b8f2ca2be8d0a9f04df2feadad5ddc1bb73c88/docs/t-digest-paper/histo.pdf>.

category:             Numeric
abi:                  f95716cd9c8506fab8de5e1e1052515a
exposed:              True
exposed-modules:
    Data.TDigest Data.TDigest.Internal Data.TDigest.NonEmpty
    Data.TDigest.Postprocess Data.TDigest.Postprocess.Internal
    Data.TDigest.Tree Data.TDigest.Tree.Internal
    Data.TDigest.Tree.NonEmpty Data.TDigest.Tree.Postprocess
    Data.TDigest.Vector Data.TDigest.Vector.Internal
    Data.TDigest.Vector.NonEmpty Data.TDigest.Vector.Postprocess

import-dirs:          /usr/lib/ghc-9.0.1/site-local/tdigest-0.2.1.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/tdigest-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/tdigest-0.2.1.1
hs-libraries:         HStdigest-0.2.1.1-CR2sQLb4NUj6mvxIST6jsM
depends:
    base-4.15.0.0 base-compat-0.11.2-EfuzzJ3SbjR74eBdJgKfBC
    binary-0.8.8.0 deepseq-1.4.5.0
    reducers-3.12.3-GqXpNWnfTTPGw01jTE81Nq
    semigroupoids-5.3.5-DgalaybhhkJASeBNYVuGaQ transformers-0.5.6.2
    vector-0.12.3.0-7AyAfn90uRLJwvulX46pQG
    vector-algorithms-0.8.0.4-KDi9Z5tJW2y2zQ5Bmwii66

haddock-interfaces:   /usr/share/doc/haskell-tdigest/html/tdigest.haddock
haddock-html:         /usr/share/doc/haskell-tdigest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
